@@ -196,6 +196,11 @@ class Screen(Generic[ScreenResultType], Widget):
     you can set the [sub_title][textual.screen.Screen.sub_title] attribute.
     """
 
+    HORIZONTAL_BREAKPOINTS: ClassVar[list[tuple[int, str]]] | None = None
+    """Horizontal breakpoints, will override [App.HORIZONTAL_BREAKPOINTS][textual.app.App.HORIZONTAL_BREAKPOINTS] if not `None`."""
+    VERTICAL_BREAKPOINTS: ClassVar[list[tuple[int, str]]] | None = None
+    """Vertical breakpoints, will override [App.VERTICAL_BREAKPOINTS][textual.app.App.VERTICAL_BREAKPOINTS] if not `None`."""
+
     focused: Reactive[Widget | None] = Reactive(None)
     """The focused [widget][textual.widget.Widget] or `None` for no focus.
     To set focus, do not update this value directly. Use [set_focus][textual.screen.Screen.set_focus] instead."""
@@ -1313,14 +1318,16 @@ class Screen(Generic[ScreenResultType], Widget):
 
     def _screen_resized(self, size: Size) -> None:
         """Called by App when the screen is resized."""
-        if self.stack_updates:
+        if self.stack_updates and self.is_attached:
             self._refresh_layout(size)
 
     def _on_screen_resume(self) -> None:
         """Screen has resumed."""
         if self.app.SUSPENDED_SCREEN_CLASS:
             self.remove_class(self.app.SUSPENDED_SCREEN_CLASS)
+
         self.stack_updates += 1
+
         self.app._refresh_notifications()
         size = self.app.size
 
@@ -1335,10 +1342,11 @@ class Screen(Generic[ScreenResultType], Widget):
                         self.set_focus(widget)
                         break
 
-        self._compositor_refresh()
-        self.app.stylesheet.update(self)
-        self._refresh_layout(size)
-        self.refresh()
+        if self.is_attached:
+            self._compositor_refresh()
+            self.app.stylesheet.update(self)
+            self._refresh_layout(size)
+            self.refresh()
 
     def _on_screen_suspend(self) -> None:
         """Screen has suspended."""
@@ -1354,6 +1362,41 @@ class Screen(Generic[ScreenResultType], Widget):
         for screen in self.app._background_screens:
             screen._screen_resized(event.size)
 
+        horizontal_breakpoints = (
+            self.app.HORIZONTAL_BREAKPOINTS
+            if self.HORIZONTAL_BREAKPOINTS is None
+            else self.HORIZONTAL_BREAKPOINTS
+        ) or []
+
+        vertical_breakpoints = (
+            self.app.VERTICAL_BREAKPOINTS
+            if self.VERTICAL_BREAKPOINTS is None
+            else self.VERTICAL_BREAKPOINTS
+        ) or []
+
+        width, height = event.size
+        if horizontal_breakpoints:
+            self._set_breakpoints(width, horizontal_breakpoints)
+        if vertical_breakpoints:
+            self._set_breakpoints(height, vertical_breakpoints)
+
+    def _set_breakpoints(
+        self, dimension: int, breakpoints: list[tuple[int, str]]
+    ) -> None:
+        """Set horizontal or vertical breakpoints.
+
+        Args:
+            dimension: Either the width or the height.
+            breakpoints: A list of breakpoints.
+
+        """
+        class_names = [class_name for _breakpoint, class_name in breakpoints]
+        self.remove_class(*class_names)
+        for breakpoint, class_name in sorted(breakpoints, reverse=True):
+            if dimension >= breakpoint:
+                self.add_class(class_name)
+                return
+
     def _update_tooltip(self, widget: Widget) -> None:
         """Update the content of the tooltip."""
         try:
