@@ -113,6 +113,9 @@ TextArea {
     padding: 0 1;
     color: $foreground;
     background: $surface;
+    &.-textual-compact {
+        border: none !important;
+    }
     & .text-area--cursor {
         text-style: $input-cursor-text-style;
     }
@@ -368,6 +371,9 @@ TextArea {
     The document can still be edited programmatically via the API.
     """
 
+    compact: reactive[bool] = reactive(False, toggle_class="-textual-compact")
+    """Enable compact display?"""
+
     _cursor_visible: Reactive[bool] = reactive(False, repaint=False, init=False)
     """Indicates where the cursor is in the blink cycle. If it's currently
     not visible due to blinking, this is False."""
@@ -420,6 +426,7 @@ TextArea {
         classes: str | None = None,
         disabled: bool = False,
         tooltip: RenderableType | None = None,
+        compact: bool = False,
     ) -> None:
         """Construct a new `TextArea`.
 
@@ -438,6 +445,7 @@ TextArea {
             classes: One or more Textual CSS compatible class names separated by spaces.
             disabled: True if the widget is disabled.
             tooltip: Optional tooltip.
+            compact: Enable compact style (without borders).
         """
         super().__init__(name=name, id=id, classes=classes, disabled=disabled)
 
@@ -492,6 +500,11 @@ TextArea {
         self._cursor_offset = (0, 0)
         """The virtual offset of the cursor (not screen-space offset)."""
 
+        self.set_reactive(TextArea.soft_wrap, soft_wrap)
+        self.set_reactive(TextArea.read_only, read_only)
+        self.set_reactive(TextArea.show_line_numbers, show_line_numbers)
+        self.set_reactive(TextArea.line_number_start, line_number_start)
+
         self._set_document(text, language)
 
         self.language = language
@@ -502,16 +515,13 @@ TextArea {
         reactive is set as a string, the watcher will update this attribute to the
         corresponding `TextAreaTheme` object."""
 
-        self.set_reactive(TextArea.soft_wrap, soft_wrap)
-        self.set_reactive(TextArea.read_only, read_only)
-        self.set_reactive(TextArea.show_line_numbers, show_line_numbers)
-        self.set_reactive(TextArea.line_number_start, line_number_start)
-
         self.tab_behavior = tab_behavior
 
         if tooltip is not None:
             self.tooltip = tooltip
 
+        self.compact = compact
+
     @classmethod
     def code_editor(
         cls,
@@ -530,6 +540,7 @@ TextArea {
         classes: str | None = None,
         disabled: bool = False,
         tooltip: RenderableType | None = None,
+        compact: bool = False,
     ) -> TextArea:
         """Construct a new `TextArea` with sensible defaults for editing code.
 
@@ -549,6 +560,7 @@ TextArea {
             classes: One or more Textual CSS compatible class names separated by spaces.
             disabled: True if the widget is disabled.
             tooltip: Optional tooltip
+            compact: Enable compact style (without borders).
         """
         return cls(
             text,
@@ -565,6 +577,7 @@ TextArea {
             classes=classes,
             disabled=disabled,
             tooltip=tooltip,
+            compact=compact,
         )
 
     @staticmethod
@@ -1008,7 +1021,7 @@ TextArea {
         width, _ = self.scrollable_content_region.size
         cursor_width = 1
         if self.soft_wrap:
-            return width - self.gutter_width - cursor_width
+            return max(0, width - self.gutter_width - cursor_width)
         return 0
 
     def _rewrap_and_refresh_virtual_size(self) -> None:
